Pi Touch GUI is a touchscreen GUI for the Raspberry PI.  It is inspired and
founded on work from the offical Raspberry Pi touchscreen, and by the
Star Trek-inspired LCARS UI by Toby Kurian.

See also:

https://github.com/pimoroni/python-multitouch/blob/master/library/setup.py
https://github.com/tobykurien/rpi_lcars